@@ -651,7 +651,7 @@ bool KCHMMainWindow::parseCmdLineArgs( )
 			exit (1);
 		}
 		else
-			filename = TQSTring::fromLocal8Bit(tqApp->argv()[i]);
+			filename = TQString::fromLocal8Bit(tqApp->argv()[i]);
 	}
 #endif
 
